==> igniteui-react-16.16.2.tgz: package/esm5/lib/MaskInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { InputBase } from "./InputBase";
import { MaskInputDir_$type } from "./MaskInputDir";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
/**
 * @hidden
 */
var MaskInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MaskInput, _super);
    function MaskInput() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(MaskInput.prototype, "y", {
        get: function () {
            var ret_ = this.f.c("dir");
            ret_ = enumGetBox(MaskInputDir_$type, EnumUtil.getEnumValue(MaskInputDir_$type, EnumUtil.parse(MaskInputDir_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(MaskInputDir_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(MaskInputDir_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("dir", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "aa", {
        get: function () {
            var ret_ = this.f.c("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "z", {
        get: function () {
            var ret_ = this.f.c("valueMode");
            ret_ = enumGetBox(MaskInputValueMode_$type, EnumUtil.getEnumValue(MaskInputValueMode_$type, EnumUtil.parse(MaskInputValueMode_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(MaskInputValueMode_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(MaskInputValueMode_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("valueMode", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "ad", {
        get: function () {
            var ret_ = this.f.c("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "ab", {
        get: function () {
            var ret_ = this.f.c("mask");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("mask", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "ac", {
        get: function () {
            var ret_ = this.f.c("prompt");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("prompt", value_);
        },
        enumerable: false,
        configurable: true
    });
    MaskInput.prototype.af = function () {
        this.nativeElement.connectedCallback();
    };
    MaskInput.prototype.ag = function () {
        this.nativeElement.reportValidity();
    };
    MaskInput.prototype.ai = function (a) {
        this.nativeElement.setCustomValidity(a);
    };
    MaskInput.prototype.ae = function () {
        this.nativeElement.checkValidity();
    };
    MaskInput.prototype.ah = function () {
        this.nativeElement.select();
    };
    MaskInput.$t = markType(MaskInput, 'MaskInput', InputBase.$);
    return MaskInput;
}(InputBase));
export { MaskInput };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/MaskInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { MaskInputBase } from "./MaskInputBase";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var MaskInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MaskInput, _super);
    function MaskInput() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(MaskInput.prototype, "ae", {
        get: function () {
            var ret_ = this.f.n("valueMode");
            ret_ = enumGetBox(MaskInputValueMode_$type, EnumUtil.getEnumValue(MaskInputValueMode_$type, this.f.f(MaskInputValueMode_$type, ret_)));
            return EnumUtil.getEnumValue(MaskInputValueMode_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(MaskInputValueMode_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("valueMode", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "ag", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInput.prototype, "af", {
        get: function () {
            var ret_ = this.f.n("mask");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("mask", value_);
        },
        enumerable: false,
        configurable: true
    });
    MaskInput.prototype.ai = function () {
        this.nativeElement.reportValidity();
    };
    MaskInput.prototype.ah = function () {
        this.nativeElement.checkValidity();
    };
    MaskInput.$t = markType(MaskInput, 'MaskInput', MaskInputBase.$);
    return MaskInput;
}(MaskInputBase));
export { MaskInput };
